Index: /lm-sensors/trunk/prog/dump/i2cbusses.c
===================================================================
--- /lm-sensors/trunk/prog/dump/i2cbusses.c	(revision 4432)
+++ /lm-sensors/trunk/prog/dump/i2cbusses.c	(revision 4861)
@@ -186,5 +186,5 @@
 				continue;
 			}
-			if((border = index(x, '\n')) != NULL)
+			if((border = strchr(x, '\n')) != NULL)
 				*border = 0;
 			if(count++ == 0 && !procfmt)

Index: /lm-sensors/trunk/lib/proc.c
===================================================================
--- /lm-sensors/trunk/lib/proc.c	(revision 4751)
+++ /lm-sensors/trunk/lib/proc.c	(revision 4861)
@@ -94,14 +94,14 @@
     if (strlen(line) > 0)
       line[strlen(line)-1] = '\0';
-    if (! (border = rindex(line,'\t')))
+    if (! (border = strrchr(line,'\t')))
       goto ERROR;
     /* Skip algorithm name */
     *border='\0';
-    if (! (border = rindex(line,'\t')))
+    if (! (border = strrchr(line,'\t')))
       goto ERROR;
     if (! (entry.adapter = strdup(border + 1)))
       goto FAT_ERROR;
     *border='\0';
-    if (! (border = rindex(line,'\t')))
+    if (! (border = strrchr(line,'\t')))
       goto ERROR;
     *border='\0';
@@ -156,6 +156,6 @@
 		strcat(n, "/");
 		strcpy(altn, n);
-		/* use rindex to append sysname to n */
-		getsysname(the_feature, rindex(n, '\0'), &mag, rindex(altn, '\0'));
+		/* use strrchr to append sysname to n */
+		getsysname(the_feature, strrchr(n, '\0'), &mag, strrchr(altn, '\0'));
 		if ((f = fopen(n, "r")) != NULL
 		 || (f = fopen(altn, "r")) != NULL) {
@@ -199,6 +199,6 @@
 		strcat(n, "/");
 		strcpy(altn, n);
-		/* use rindex to append sysname to n */
-		getsysname(the_feature, rindex(n, '\0'), &mag, rindex(altn, '\0'));
+		/* use strrchr to append sysname to n */
+		getsysname(the_feature, strrchr(n, '\0'), &mag, strrchr(altn, '\0'));
 		if ((f = fopen(n, "w")) != NULL
 		 || (f = fopen(altn, "w")) != NULL) {